@@ -20,6 +20,11 @@ function (X, FUN, ..., cl = NULL)
                     cl <- NULL
             }
         }
+        ## deal with future
+        if (identical(cl, "future") && (!requireNamespace("future") || !requireNamespace("future.apply"))) {
+            warning("You need some packages for cl='future' to work: install.packages('future.apply')")
+            cl <- NULL
+        }
     }
     nout <- as.integer(getOption("pboptions")$nout)
     ## sequential evaluation
@@ -54,10 +59,29 @@ function (X, FUN, ..., cl = NULL)
                 rval[i] <- list(PAR_FUN(cl, X[Split[[i]]], FUN, ...))
                 setpb(pb, i)
             }
+        ## future backend
+        } else if (identical(cl, "future")) {
+            requireNamespace("future")
+            requireNamespace("future.apply")
+            if (!dopb())
+                return(future.apply::future_lapply(X, FUN, ...,
+                    future.stdout = FALSE))
+            Split <- splitpb(length(X), future::nbrOfWorkers(), nout = nout)
+            B <- length(Split)
+            pb <- startpb(0, B)
+            on.exit(closepb(pb), add = TRUE)
+            rval <- vector("list", B)
+            for (i in seq_len(B)) {
+                rval[i] <- list(future.apply::future_lapply(X[Split[[i]]], FUN, ...,
+                    future.stdout = FALSE))
+                setpb(pb, i)
+            }
         ## multicore type forking
         } else {
             if (!dopb())
-                return(parallel::mclapply(X, FUN, ..., mc.cores = as.integer(cl)))
+                return(parallel::mclapply(X, FUN, ..., 
+                    mc.cores = as.integer(cl),
+                    mc.silent = TRUE))
             ## define split here and use that for counter
             Split <- splitpb(length(X), as.integer(cl), nout = nout)
             B <- length(Split)
@@ -66,7 +90,8 @@ function (X, FUN, ..., cl = NULL)
             rval <- vector("list", B)
             for (i in seq_len(B)) {
                 rval[i] <- list(parallel::mclapply(X[Split[[i]]], FUN, ...,
-                    mc.cores = as.integer(cl)))
+                    mc.cores = as.integer(cl),
+                    mc.silent = TRUE))
                 setpb(pb, i)
             }
         }
